\name{summary.whatif}
\alias{summary.whatif}
\title{Summary of "whatif" Object}
\description{
Prints a summary of an object returned by the function \code{whatif},
an object of class "whatif", to the screen.
}
\usage{
\method{summary}{whatif}(object, print.freq = FALSE)
}
\arguments{
  \item{object}{An object of class "whatif", produced by a call to
    the function \code{whatif}.}
  \item{print.freq}{A Boolean; should cumulative frequencies be printed
    for each counterfactual?  Default is FALSE.}
}
\value{
  For each counterfactual, a printout on the screen of the following:
  the result of the convex hull test; the value of the summary
  statistic; the average of the summary statistic over all counterfactuals;
  and the cumulative frequencies of the Gower distances, if
  you requested their printing by setting the argument
  \code{print.freq} equal to TRUE.  Also printed are the number of
  counterfactuals evaluated and the geometric variance of the observed
  covariate data.
}
\references{King, Gary and Langche Zeng.  2006a.  "The Dangers of 
  Extreme Counterfactuals."  \emph{Political Analysis,} forthcoming.
  Preprint available from \url{http://gking.harvard.edu}.

  King, Gary and Langche Zeng.  2006b.  "When Can History Be Our Guide?
  The Pitfalls of Counterfactual Inference."  \emph{International Studies Quarterly,}
  forthcoming.  Preprint available from \url{http://gking.harvard.edu}.}
\author{Stoll, Heather \email{hstoll@polsci.ucsb.edu}, King, Gary
  \email{king@harvard.edu} and Zeng, Langche \email{zeng@ucsd.edu}}
\seealso{
  \code{\link{whatif}},
  \code{\link{plot.whatif}}
}
\examples{
##  Create example data sets and counterfactuals
my.cfact <- matrix(rnorm(3*5), ncol = 5)
my.data <- matrix(rnorm(100*5), ncol = 5)

##  Evaluate counterfactuals
my.result <- whatif(data = my.data, cfact = my.cfact)

##  Print summary
summary(my.result)
}
\keyword{print}
